<?php if (!defined('ABSPATH')) die;

function pipdig_youtube_page_init() {

	register_setting('pipdig_youtube_options_page', 'pipdig_youtube');
	
	add_settings_section(
		'pipdig_youtube_options_page_section', 
		'',
		'', 
		'pipdig_youtube_options_page'
	);
	
	add_settings_field( 
		'access_token', 
		'API Key', 
		'p3_youtube_at_render', 
		'pipdig_youtube_options_page', 
		'pipdig_youtube_options_page_section' 
	);
	
}
add_action('admin_init', 'pipdig_youtube_page_init');


function p3_youtube_at_render() {
	$youtube_deets = get_option('pipdig_youtube');
	$access_token = '';
	if (!empty($youtube_deets['access_token'])) { 
		$access_token = sanitize_text_field($youtube_deets['access_token']);
	}
	?>
	<input type="text" class="large-text code" id="pd_yt_access_token" name="pipdig_youtube[access_token]" autocomplete="off" value="<?php echo $access_token; ?>" /> <?php
}


function pipdig_youtube_options_page() { 

	// clear YT transients
	global $wpdb;
	$wpdb->query("DELETE FROM $wpdb->options WHERE option_name LIKE '%\_transient_p3_yt\_%'");

	?>
	<div class="wrap">
	
	<h1 class="wp-heading-inline">YouTube Settings</h1>
	
	<?php
	
	$show_debug = false;
	
	$access_token = '';
	$you_are_connected_msg = '';
	
	$youtube_deets = get_option('pipdig_youtube');
	if (!empty($youtube_deets['access_token'])) {
		$access_token = sanitize_text_field($youtube_deets['access_token']);
	}
	
	if ($access_token) {
		
		echo '<div class="card" id="pd_ig_results" style="margin-bottom: 30px;">';
		
		if (!function_exists('curl_version')) {
			echo '<p><span class="piperror"><span class="dashicons dashicons-no"></span> Error! cURL is not enabled or is an old version. Please contact your web hosting company and ask them to upgrade cURL and PHP to the newest version they offer.</span></p>';
		}
		
		$url = 'https://www.googleapis.com/youtube/v3/search?order=date&part=snippet&type=video&channelId=UCvprer5zxH7xlWYs99Vdgew&key='.$access_token.'&maxResults=1';
		$args = array('timeout' => 10);
		$response = wp_remote_retrieve_body(wp_remote_get($url, $args));
		
		$body = json_decode($response);
		/*
		echo '<pre>';
		print_r($body);
		echo '</pre>';
		*/
		if (isset($body->pageInfo->totalResults) && absint($body->pageInfo->totalResults) > 0) {
			$show_steps = true;
			$username = sanitize_text_field($body->items[0]->snippet->channelTitle);
			$you_are_connected_msg = "<p>You're already connected to YouTube. If you need to change to a different YouTube account, you can do so below.</p><p>---</p>";
			echo '<p><span class="pipsuccess"><span class="dashicons dashicons-yes"></span> Success! This site is connected to YouTube. You can now use the <a href="https://support.pipdig.co/articles/wordpress-youtube-widget/" target="_blank">YouTube widget</a>.</span></p>';
		} else {
			echo '<p><span class="piperror"><span class="dashicons dashicons-no"></span> Error! Could not connect to YouTube. Please try creating a new API Key or try again later.</span></p>';
			$show_debug = true;
		}
		echo '</div>';
		
	}
	?>
	
	<div class="card">
	
	<style scoped>
	.form-table th {
		display: none;
	}
	.form-table td {
		padding: 0;
	}
	.form-table td
	.piperror {
		color: red;
	}
	.pipsuccess {
		color: green;
		font-size: 15px;
	}
	.pipsuccess a {
		color: green;
	}
	#p3_new_ig_twentytwenty_notice {
		display: none !important;
	}
	</style>
	
	<form action='options.php' method='post'>
		<?php echo $you_are_connected_msg; ?>
		
		<p>Google requires you to create an app to display your videos in the YouTube widget.</p>
		<p>Please see <a href="https://support.pipdig.co/articles/youtube-api-key/" target="_blank" style="color: red">this guide</a> to create an API Key. Copy and paste the key below:</p>
		
		<?php
		settings_fields('pipdig_youtube_options_page');
		do_settings_sections('pipdig_youtube_options_page');
		submit_button();
		?>
	</form>
	
	</div>
	
	<div class="card" id="pd_yt_debug" style="display: none">
		<h2>Debug Info</h2>
		<textarea class="large-text code">
		<?php echo esc_html($response); ?>
		</textarea>
	</div>
	
	</div>
	<?php if ($show_debug) { ?>
	<script>
	jQuery(document).ready(function($) {
		$('#pd_yt_debug').show();
	});
	</script>
	<?php } ?>
	<?php
}
